[Lldb-commits] [lldb] r113206 - /lldb/trunk/test/help/TestHelp.py

Johnny Chen johnny.chen at apple.com
Tue Sep 7 09:19:35 PDT 2010


Author: johnny
Date: Tue Sep  7 11:19:35 2010
New Revision: 113206

URL: http://llvm.org/viewvc/llvm-project?rev=113206&view=rev
Log:
LLDB command "set term-width 0" needs to be changed to "settings set term-width 0"
after the recent checkin.

Modified:
    lldb/trunk/test/help/TestHelp.py

Modified: lldb/trunk/test/help/TestHelp.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/help/TestHelp.py?rev=113206&r1=113205&r2=113206&view=diff
==============================================================================
--- lldb/trunk/test/help/TestHelp.py (original)
+++ lldb/trunk/test/help/TestHelp.py Tue Sep  7 11:19:35 2010
@@ -19,8 +19,8 @@
             startstr = 'The following is a list of built-in, permanent debugger commands')
 
     def test_help_should_not_hang_emacsshell(self):
-        """Command 'set term-width 0' should not hang the help command."""
-        self.runCmd("set term-width 0")
+        """Command 'settings set term-width 0' should not hang the help command."""
+        self.runCmd("settings set term-width 0")
         self.expect("help",
             startstr = 'The following is a list of built-in, permanent debugger commands')
 





More information about the lldb-commits mailing list